@@ -100,7 +100,7 @@ setup_workers(int num_workers)
 			}
 
 			/* Hardcode a search path to avoid injections into public or pg_temp */
-			pgut_command(conn, "SET search_path TO pg_catalog, pg_temp", 0, NULL);
+			pgut_command(conn, "SET search_path TO pg_catalog, pg_temp, public", 0, NULL);
 
             /* Make sure each worker connection can work in non-blocking
              * mode.
